.. Sage Constructions documentation master file, created by sphinx-quickstart on Fri Aug 22 12:10:42 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _constructions:

======================
欢迎来到 Sage 构建指南
======================

本文档收集了一些关于“如何在 Sage 中构建...”相关问题的答案。
尽管在使用手册、教程或 Python 代码的文档中可以找到许多这方面的材料，
但希望本文档能够为一般用户提供一些如何开始有效使用 Sage 的基本示例。

此作品采用 `Creative Commons Attribution-Share Alike
3.0 License`__ 许可。

__ http://creativecommons.org/licenses/by-sa/3.0/

请将建议、补充、修正发送到 ``sage-devel`` Google 讨论组！

Sage wiki http://wiki.sagemath.org/ 包含丰富的信息。
此外，所有内容均可在 Sage 网页界面 http://sagecell.sagemath.org/ 上测试。


.. toctree::
   :maxdepth: 2

   calculus
   plotting
   groups
   linear_algebra
   linear_codes
   rep_theory
   rings
   polynomials
   number_theory
   modular_forms
   elliptic_curves
   number_fields
   algebraic_geometry
   interface_issues
   contributions


索引与表格
==========

* :ref:`genindex`
* :ref:`search`

